Class: RunApi::RunwayAleph::Client

Inherits:
Core::Client
  • Object
show all
Defined in:
lib/runapi/runway_aleph/client.rb

Overview

Runway Aleph prompt-driven video editing API client. Unlike generation from scratch, Runway Aleph transforms an existing video using a text prompt, with optional style reference images.

Examples:

client = RunApi::RunwayAleph::Client.new(api_key: "your-api-key")
result = client.edit_video.run(
  prompt: "Make it look like a watercolor painting",
  source_video_url: "https://example.com/input.mp4"
)

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_key: nil, **options) ⇒ Client

Returns a new instance of Client.



19
20
21
22
# File 'lib/runapi/runway_aleph/client.rb', line 19

def initialize(api_key: nil, **options)
  super
  @edit_video = Resources::EditVideo.new(http)
end

Instance Attribute Details

#edit_videoResources::EditVideo (readonly)

Returns Prompt-driven video editing with optional style reference.

Returns:



17
18
19
# File 'lib/runapi/runway_aleph/client.rb', line 17

def edit_video
  @edit_video
end