Class: RunApi::RunwayAleph::Client
- Inherits:
-
Core::Client
- Object
- Core::Client
- RunApi::RunwayAleph::Client
- Defined in:
- lib/runapi/runway_aleph/client.rb
Overview
Runway Aleph prompt-driven video editing API client. Unlike generation from scratch, Runway Aleph transforms an existing video using a text prompt, with optional style reference images.
Instance Attribute Summary collapse
-
#edit_video ⇒ Resources::EditVideo
readonly
Prompt-driven video editing with optional style reference.
Instance Method Summary collapse
-
#initialize(api_key: nil, **options) ⇒ Client
constructor
A new instance of Client.
Constructor Details
Instance Attribute Details
#edit_video ⇒ Resources::EditVideo (readonly)
Returns Prompt-driven video editing with optional style reference.
17 18 19 |
# File 'lib/runapi/runway_aleph/client.rb', line 17 def edit_video @edit_video end |